pub struct HardBlock {
pub indent: usize,
pub lhs: &'static str,
pub rhs: &'static str,
pub joint: PrettyTree,
}Expand description
A soft block is a block that is not required to be on a new line.
{a, b, c}
{
a,
b,
}Fields
indent: usizeThe indentation of the soft block
lhs: &'static strThe left hand side of the soft block
rhs: &'static strThe right hand side of the soft block
joint: PrettyTreeThe joint node of the soft block
Implementations
Sourceimpl HardBlock
impl HardBlock
Sourcepub fn parentheses() -> Self
pub fn parentheses() -> Self
Build a new soft block with the parentheses syntax
Sourcepub fn curly_braces() -> Self
pub fn curly_braces() -> Self
Build a new soft block with the curly braces syntax
Sourcepub fn with_joint(self, joint: PrettyTree) -> Self
pub fn with_joint(self, joint: PrettyTree) -> Self
Set the joint node of the soft block
Sourceimpl HardBlock
impl HardBlock
Sourcepub fn join_slice<T: PrettyPrint>(
&self,
slice: &[T],
theme: &PrettyProvider,
) -> PrettyTree
pub fn join_slice<T: PrettyPrint>( &self, slice: &[T], theme: &PrettyProvider, ) -> PrettyTree
Join a slice of pretty printables with the soft block