pub struct PrettyProvider<'a> { /* private fields */ }

Implementations

source

impl<'a> PrettyProvider<'a>

source

pub fn new() -> Self

source

impl<'a> PrettyProvider<'a>where 'a: 'static,

source

pub fn nil(&'a self) -> PrettyTree<'a>

source

pub fn space(&'a self) -> PrettyTree<'a>

source

pub fn hardline(&'a self) -> PrettyTree<'a>

source

pub fn text<S>(&'a self, text: S) -> PrettyTree<'a>where S: Into<Cow<'static, str>>,

source

pub fn keyword<S>(&'a self, text: S) -> PrettyTree<'a>where S: Into<Cow<'static, str>>,

source

pub fn identifier<S>(&'a self, text: S) -> PrettyTree<'a>where S: Into<Cow<'static, str>>,

source

pub fn generic<S>(&'a self, text: S) -> PrettyTree<'a>where S: Into<Cow<'static, str>>,

source

pub fn argument<S>(&'a self, text: S) -> PrettyTree<'a>where S: Into<Cow<'static, str>>,

source

pub fn operator<S>(&'a self, text: S) -> PrettyTree<'a>where S: Into<Cow<'static, str>>,

source

pub fn string_style(&self) -> ColorSpec

source

pub fn number_style(&self) -> ColorSpec

source

pub fn macro_style(&self) -> ColorSpec

source

impl<'a> PrettyProvider<'a>

source

pub fn concat<I>(&'a self, docs: I) -> PrettyTree<'a>where I: IntoIterator, I::Item: Pretty<'a, Arena<'a, ColorSpec>, ColorSpec>,

Allocate a document concatenating the given documents.

source

pub fn intersperse<T, S>(&'a self, terms: &[T], joint: S) -> PrettyTree<'a>where T: PrettyPrint, S: Pretty<'a, Arena<'a, ColorSpec>, ColorSpec> + Clone,

Allocate a document that intersperses the given separator S between the given documents [A, B, C, ..., Z], yielding [A, S, B, S, C, S, ..., S, Z].

Compare the intersperse method from the itertools crate.

NOTE: The separator type, S may need to be cloned. Consider using cheaply cloneable ptr like RefDoc or RcDoc

source

pub fn join<T, S>(&'a self, terms: &[T], joint: &'static str) -> PrettyTree<'a>where T: PrettyPrint, S: Pretty<'a, Arena<'a, ColorSpec>, ColorSpec> + Clone,

Allocate a document that intersperses the given separator S between the given documents [A, B, C, ..., Z], yielding [A, S, B, S, C, S, ..., S, Z].

Compare the intersperse method from the itertools crate.

NOTE: The separator type, S may need to be cloned. Consider using cheaply cloneable ptr like RefDoc or RcDoc